@@ -25,10 +25,20 @@ our $mod = {
     module=>'PDL::Graphics::Simple::PLplot',
     engine => 'PDL::Graphics::PLplot',
     synopsis=> 'PLplot (nice plotting, sloooow images)',
-    pgs_version=> '1.005'
+    pgs_version=> '1.006',
 };
 PDL::Graphics::Simple::register( 'PDL::Graphics::Simple::PLplot' );
 
+my @DEVICES = qw(
+  qtwidget wxwidgets xcairo xwin wingcc
+);
+our $guess_filetypes = {
+    ps  =>  ['pscairo','psc', 'psttfc', 'ps'],
+    svg =>  ['svgcairo','svg','svgqt'],
+    pdf => ['pdfcairo','pdfqt'],
+    png => ['pngcairo','pngqt']
+};
+
 ##########
 # PDL::Graphics::Simple::PLplot::check
 # Checker
@@ -78,7 +88,7 @@ sub check {
     else {
       my $pid = fork();
       unless(defined($pid)) {
- 	print STDERR "Fork failed in PLplot probe -- returning 0\n";
+	print STDERR +($mod->{msg} = "Fork failed in PLplot probe -- returning 0"), "\n";
 	return 0;
       }
 
@@ -115,24 +125,14 @@ sub check {
 	}
     }
 
-    if( $mod->{devices}->{'xcairo'} ) {
-	$mod->{disp_dev} = 'xcairo';
-    } elsif( $mod->{devices}->{'xwin'} ) {
-	$mod->{disp_dev} = 'xwin';
-    } elsif( $mod->{devices}->{'wingcc'} ) {
-	$mod->{disp_dev} = 'wingcc';
+    if( my ($good_dev) = grep $mod->{devices}{$_}, @DEVICES ) {
+	$mod->{disp_dev} = $good_dev;
     } else {
 	$mod->{ok} = 0;
+	$mod->{msg} = "No suitable display device found";
 	return 0;
     }
 
-    our $guess_filetypes = {
-	ps  =>  ['pscairo','psc', 'psttfc', 'ps'],
-	svg =>  ['svgcairo','svg'],
-	pdf => ['pdfcairo'],
-	png => ['pngcairo']
-    };
-
     our $filetypes;
     $filetypes = {};
 
@@ -147,6 +147,7 @@ sub check {
 
     unless($filetypes->{ps}) {
 	$mod->{ok} = 0;
+	$mod->{msg} = "No PostScript found";
 	return 0;
     }
 
